LaShareContentTypes class

supported share content types

Constructors

LaShareContentTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

file ShareContentType
no setter
image ShareContentType
no setter
music ShareContentType
no setter
text ShareContentType
no setter
video ShareContentType
no setter
webpage ShareContentType
no setter