ShareParamsBean class

Constructors

ShareParamsBean({String? title, String? text, String? imageFilePath, String? webUrl, String? musicUrl, String? videoUrl, String? filePath, String? pkgNameAndroid, Language language = Language.EN, required ShareContentType contentType, required SharePlatform platform})

Properties

contentType ShareContentType
final
filePath String?
file 类型必须传
final
hashCode int
The hash code for this object.
no setterinherited
imageFilePath String?
image 类型必须传,webpage 类型可选
final
language Language
分享弹窗多语言适配可选,默认英文
final
musicUrl String?
final
pkgNameAndroid String?
Android 包名,用于在系统分享时指定包名
final
platform SharePlatform
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
text 类型必须传,webpage 类型可选
final
title String?
webpage 类型可选
final
videoUrl String?
final
webUrl String?
webpage 类型必须传
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toChannelMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited