SharePlatforms class

Constructors

SharePlatforms()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

facebook SharePlatform
final
line SharePlatform
final
native SharePlatform
final
twitter SharePlatform
final
wechatSession SharePlatform
final
wechatTimeline SharePlatform
final
whatsApp SharePlatform
final

Static Methods

getPlatformWithId(int id) SharePlatform